import React, { useState, useEffect } from 'react';
import { connect } from 'umi';
import { Avatar, Modal, Button, Spin, Image, Pagination } from 'antd';
import {} from '@ant-design/icons';
import { RA } from '@/utils/method';

// icon
import IconPdf from '@/assets/icon-pdf.png';
import IconImg from '@/assets/icon-img.png';
import IconNone from '@/assets/logo_icon_bg.png';

import PDF from 'react-pdf-js';

import { stringSplit } from '@/utils/string';

const PreView = (props: any) => {
  const module = 'CellList';

  const { CellList, dispatch, OpenUrl, loading } = props;

  const [Icon, setIcon] = useState(null as any); // 图标显示哪一个控制
  const [ModalTip, setModalTip] = useState(false); // 弹窗控制
  const [ModalInfo, setModalInfo] = useState(null as any); // 弹窗信息
  //pdf 页码内容
  const [numPages, setNumPages] = useState(1 as any); // 总页码数
  const [pageNumber, setPageNumber] = useState(1); // 当前页码数

  // 图标显示判断
  useEffect(() => {
    console.log(OpenUrl);
    if (OpenUrl) {
      OpenUrl.match(/\.([^\.]+)$/)[1].toLowerCase() == 'pdf' ? setIcon(IconPdf) : setIcon(IconImg);
    } else {
      setIcon(IconNone);
    }
  }, [OpenUrl]);

  // 监听是否获取到地址以及发生改变
  useEffect(() => {
    if (CellList.imgUrl != null) {
      let info = {
        name: CellList.imgUrl.name,
        type: CellList.imgUrl.name.match(/\.([^\.]+)$/)[1].toLowerCase(),
        url: CellList.imgUrl.url,
      };
      setModalInfo(info);
      // openDows(imgUrl.url, imgUrl.name);
    }
  }, [CellList.imgUrl]);

  //点击预览
  const opens = () => {
    setModalTip(true);
    let msg = {
      // userToken: '',
      // type: ans.substr(ans.lastIndexOf('.') + 1),
      type: 'tosCommunityFileService',
      fileName: OpenUrl,
      extends: CellList.detailData.rows.residentialName,
    };
    RA(47, msg, module, dispatch);
  };

  // 隐藏弹窗
  const handleCancel = () => {
    setModalTip(false);
  };

  // pdf 总页数
  const onDocumentLoadSuccess = (pages: any) => {
    setNumPages(pages);
  };

  // 切换pdf 总数
  const onChangePage = (page: any) => {
    setPageNumber(page);
  };

  return (
    <>
      {/* 文件 Icon */}
      <Avatar
        shape="square"
        style={{
          color: '#f56a00',
          backgroundColor: '#F2F6FC',
          border: '1px solid #F2F6FC',
          borderRadius: 4,
        }}
        size={80}
        src={Icon}
      />
      {/* 文件名 */}
      <span style={{ display: 'inline-block', margin: '0 15px', minWidth: 200 }}>
        {OpenUrl.length > 0 ? OpenUrl : 'No Attachment!'}
      </span>
      {/* 文件操作 */}
      {OpenUrl.length > 0 ? (
        <Button type="link" onClick={opens}>
          Browse
        </Button>
      ) : (
        ''
      )}
      {/* 文件弹窗 */}
      <Modal
        visible={ModalTip}
        width={650}
        style={{ textAlign: 'center' }}
        footer={null}
        title={OpenUrl}
        onCancel={handleCancel}
      >
        <Spin spinning={loading}>
          {ModalInfo != null && ModalInfo.type == 'pdf' ? (
            <>
              <PDF
                file={ModalInfo ? stringSplit(ModalInfo.url, 'm/cash') : ''}
                page={pageNumber}
                onDocumentComplete={onDocumentLoadSuccess}
              />
              <Pagination
                style={{ textAlign: 'center', marginTop: 10, display: 'block' }}
                simple
                defaultCurrent={pageNumber}
                total={numPages * 10}
                onChange={onChangePage}
              />
            </>
          ) : (
            <Image
              src={ModalInfo ? ModalInfo.url : ''}
              preview={false}
              style={{ margin: '0 auto', textAlign: 'center' }}
            />
          )}
        </Spin>
      </Modal>
    </>
  );
};

function PreViewPorps(state: any) {
  const { CellList } = state;
  const loading = state.loading.models.CellList;
  return {
    CellList,
    loading,
  };
}
export default connect(PreViewPorps)(PreView);
